@@ -2,43 +2,44 @@ package commonTestUtils
 
 import (
 	"context"
-
-	monitoringv1 "github.com/coreos/prometheus-operator/pkg/apis/monitoring/v1"
-
+	"fmt"
 	networkaddons "github.com/kubevirt/cluster-network-addons-operator/pkg/apis"
 	"github.com/kubevirt/hyperconverged-cluster-operator/pkg/apis"
 	vmimportv1beta1 "github.com/kubevirt/vm-import-operator/pkg/apis/v2v/v1beta1"
 	consolev1 "github.com/openshift/api/console/v1"
+	monitoringv1 "github.com/prometheus-operator/prometheus-operator/pkg/apis/monitoring/v1"
 	cdiv1beta1 "kubevirt.io/containerized-data-importer/pkg/apis/core/v1beta1"
 	sspv1beta1 "kubevirt.io/ssp-operator/api/v1beta1"
+	"sigs.k8s.io/controller-runtime/pkg/log/zap"
 	"sigs.k8s.io/controller-runtime/pkg/reconcile"
 
 	"github.com/kubevirt/hyperconverged-cluster-operator/pkg/controller/common"
 	sdkapi "kubevirt.io/controller-lifecycle-operator-sdk/pkg/sdk/api"
 
+	"github.com/kubevirt/hyperconverged-cluster-operator/pkg/components"
+
 	hcov1beta1 "github.com/kubevirt/hyperconverged-cluster-operator/pkg/apis/hco/v1beta1"
 	corev1 "k8s.io/api/core/v1"
 	apiextensionsv1 "k8s.io/apiextensions-apiserver/pkg/apis/apiextensions/v1"
-	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/client-go/kubernetes/scheme"
-	logf "sigs.k8s.io/controller-runtime/pkg/runtime/log"
 
+	. "github.com/onsi/ginkgo"
 	. "github.com/onsi/gomega"
 )
 
 // Name and Namespace of our primary resource
 const (
-	Name             = "kubevirt-hyperconverged"
-	Namespace        = "kubevirt-hyperconverged"
-	Conversion_image = "quay.io/kubevirt/kubevirt-v2v-conversion:v2.0.0"
-	Vmware_image     = "quay.io/kubevirt/kubevirt-vmware:v2.0.0"
-	VirtioWinImage   = "quay.io/kubevirt/virtio-container-disk:v2.0.0"
+	Name            = "kubevirt-hyperconverged"
+	Namespace       = "kubevirt-hyperconverged"
+	ConversionImage = "quay.io/kubevirt/kubevirt-v2v-conversion:v2.0.0"
+	VmwareImage     = "quay.io/kubevirt/kubevirt-vmware:v2.0.0"
+	VirtioWinImage  = "quay.io/kubevirt/virtio-container-disk:v2.0.0"
 )
 
 var (
-	TestLogger  = logf.Log.WithName("controller_hyperconverged")
+	TestLogger  = zap.New(zap.WriteTo(GinkgoWriter), zap.UseDevMode(true)).WithName("controller_hyperconverged")
 	TestRequest = reconcile.Request{
 		NamespacedName: types.NamespacedName{
 			Name:      Name,
@@ -48,13 +49,9 @@ var (
 )
 
 func NewHco() *hcov1beta1.HyperConverged {
-	return &hcov1beta1.HyperConverged{
-		ObjectMeta: metav1.ObjectMeta{
-			Name:      Name,
-			Namespace: Namespace,
-		},
-		Spec: hcov1beta1.HyperConvergedSpec{},
-	}
+	hco := components.GetOperatorCR()
+	hco.ObjectMeta.Namespace = Namespace
+	return hco
 }
 
 func NewReq(inst *hcov1beta1.HyperConverged) *common.HcoRequest {
@@ -68,12 +65,29 @@ func NewReq(inst *hcov1beta1.HyperConverged) *common.HcoRequest {
 	}
 }
 
-func NewNodePlacement() *sdkapi.NodePlacement {
-	seconds1, seconds2 := int64(1), int64(2)
+func getNodePlacement(num1, num2 int64) *sdkapi.NodePlacement {
+	var (
+		key1 = fmt.Sprintf("key%d", num1)
+		key2 = fmt.Sprintf("key%d", num2)
+
+		val1 = fmt.Sprintf("value%d", num1)
+		val2 = fmt.Sprintf("value%d", num2)
+
+		operator1 = corev1.NodeSelectorOperator(fmt.Sprintf("operator%d", num1))
+		operator2 = corev1.NodeSelectorOperator(fmt.Sprintf("operator%d", num2))
+
+		effect1 = corev1.TaintEffect(fmt.Sprintf("effect%d", num1))
+		effect2 = corev1.TaintEffect(fmt.Sprintf("effect%d", num2))
+
+		firstVal1  = fmt.Sprintf("value%d1", num1)
+		secondVal1 = fmt.Sprintf("value%d2", num1)
+		firstVal2  = fmt.Sprintf("value%d1", num2)
+		secondVal2 = fmt.Sprintf("value%d2", num2)
+	)
 	return &sdkapi.NodePlacement{
 		NodeSelector: map[string]string{
-			"key1": "value1",
-			"key2": "value2",
+			key1: val1,
+			key2: val2,
 		},
 		Affinity: &corev1.Affinity{
 			NodeAffinity: &corev1.NodeAffinity{
@@ -81,12 +95,12 @@ func NewNodePlacement() *sdkapi.NodePlacement {
 					NodeSelectorTerms: []corev1.NodeSelectorTerm{
 						{
 							MatchExpressions: []corev1.NodeSelectorRequirement{
-								{Key: "key1", Operator: "operator1", Values: []string{"value11, value12"}},
-								{Key: "key2", Operator: "operator2", Values: []string{"value21, value22"}},
+								{Key: key1, Operator: operator1, Values: []string{firstVal1, secondVal1}},
+								{Key: key2, Operator: operator2, Values: []string{firstVal2, secondVal2}},
 							},
 							MatchFields: []corev1.NodeSelectorRequirement{
-								{Key: "key1", Operator: "operator1", Values: []string{"value11, value12"}},
-								{Key: "key2", Operator: "operator2", Values: []string{"value21, value22"}},
+								{Key: key1, Operator: operator1, Values: []string{firstVal1, secondVal1}},
+								{Key: key2, Operator: operator2, Values: []string{firstVal2, secondVal2}},
 							},
 						},
 					},
@@ -94,42 +108,18 @@ func NewNodePlacement() *sdkapi.NodePlacement {
 			},
 		},
 		Tolerations: []corev1.Toleration{
-			{Key: "key1", Operator: "operator1", Value: "value1", Effect: "effect1", TolerationSeconds: &seconds1},
-			{Key: "key2", Operator: "operator2", Value: "value2", Effect: "effect2", TolerationSeconds: &seconds2},
+			{Key: key1, Operator: corev1.TolerationOperator(operator1), Value: val1, Effect: effect1, TolerationSeconds: &num1},
+			{Key: key2, Operator: corev1.TolerationOperator(operator2), Value: val2, Effect: effect2, TolerationSeconds: &num2},
 		},
 	}
 }
 
+func NewNodePlacement() *sdkapi.NodePlacement {
+	return getNodePlacement(1, 2)
+}
+
 func NewOtherNodePlacement() *sdkapi.NodePlacement {
-	seconds3, seconds4 := int64(3), int64(4)
-	return &sdkapi.NodePlacement{
-		NodeSelector: map[string]string{
-			"key3": "value3",
-			"key4": "value4",
-		},
-		Affinity: &corev1.Affinity{
-			NodeAffinity: &corev1.NodeAffinity{
-				RequiredDuringSchedulingIgnoredDuringExecution: &corev1.NodeSelector{
-					NodeSelectorTerms: []corev1.NodeSelectorTerm{
-						{
-							MatchExpressions: []corev1.NodeSelectorRequirement{
-								{Key: "key3", Operator: "operator3", Values: []string{"value31, value32"}},
-								{Key: "key4", Operator: "operator4", Values: []string{"value41, value42"}},
-							},
-							MatchFields: []corev1.NodeSelectorRequirement{
-								{Key: "key3", Operator: "operator3", Values: []string{"value31, value32"}},
-								{Key: "key4", Operator: "operator4", Values: []string{"value41, value42"}},
-							},
-						},
-					},
-				},
-			},
-		},
-		Tolerations: []corev1.Toleration{
-			{Key: "key3", Operator: "operator3", Value: "value3", Effect: "effect3", TolerationSeconds: &seconds3},
-			{Key: "key4", Operator: "operator4", Value: "value4", Effect: "effect4", TolerationSeconds: &seconds4},
-		},
-	}
+	return getNodePlacement(3, 4)
 }
 
 var testScheme *runtime.Scheme
